// -*- C++ -*-
/*!
 * @file  HandTest.cpp
 * @brief A test module for the RH707
 * @date $Date$
 *
 * $Id$
 */

#include "HandTest.h"

// Module specification
// <rtc-template block="module_spec">
static const char* handtest_spec[] =
  {
    "implementation_id", "HandTest",
    "type_name",         "HandTest",
    "description",       "A test module for the RH707",
    "version",           "1.0.0",
    "vendor",            "RTC-Center",
    "category",          "hand",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
HandTest::HandTest(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_ComHandConsPort("ComHandCons")

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
HandTest::~HandTest()
{
}



RTC::ReturnCode_t HandTest::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  
  // Set OutPort buffer
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  m_ComHandConsPort.registerConsumer("com_hand", "ComHand", m_com_hand);
  
  // Set CORBA Service Ports
  addPort(m_ComHandConsPort);
  
  // </rtc-template>

  return RTC::RTC_OK;
}


RTC::ReturnCode_t HandTest::onFinalize()
{
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t HandTest::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t HandTest::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t HandTest::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t HandTest::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t HandTest::onExecute(RTC::UniqueId ec_id)
{
  char  command[1+1];
  short error;
  short condition;
  short mode;

  std::cout << "***** RH707 Hand Open/Close Test *****" << std::endl;
  std::cout << " A:OpenHand                           " << std::endl;
  std::cout << " B:CloseHand                          " << std::endl;
  std::cout << " C:StopHand                           " << std::endl;
  std::cout << " D:GetHandCond                        " << std::endl;
  std::cout << " E:GetHandMode                        " << std::endl;
  std::cout << "**************************************" << std::endl;
  std::cout << " =>";

  std::cin >> command;

  //error = m_com_hand->InitHand();
  //if(error != 0) std::cout << "m_com_hand->InitHand() error" << std::endl;

  if(!strcmp(command,"A")){
    error = m_com_hand->OpenHand(0);
    if(error != 0) std::cout << "m_com_hand->OpenHand() error" << std::endl;
  } else if(!strcmp(command,"B")){
    error = m_com_hand->CloseHand(0);
    if(error != 0) std::cout << "m_com_hand->CloseHand() error" << std::endl;
  } else if(!strcmp(command,"C")){
    error = m_com_hand->StopHand();
    if(error != 0) std::cout << "m_com_hand->StopHand() error" << std::endl;
  } else if(!strcmp(command,"D")){
    condition = m_com_hand->GetHandCond();
	if(condition == 1){
		std::cout << "Hand Condition: Now MOVING" << std::endl;
	}else if(condition == 2){
		std::cout << "Hand Condition: CLOSED" << std::endl;
	}else if(condition == 3){
		std::cout << "Hand Condition: OPENED" << std::endl;
	}else if(condition == 4){
		std::cout << "Hand Condition: INTERRUPTED" << std::endl;
	}else {
		std::cout << "Hand Condition: UNKNOWN" << std::endl;
	}
  } else if(!strcmp(command,"E")){
    mode = m_com_hand->GetHandMode();
	if(mode == 1){
		std::cout << "Hand Mode: OPEN" << std::endl;
	}else if(mode == 2){
		std::cout << "Hand Mode: OPEN SLOWLY" << std::endl;
	}else if(mode == 3){
		std::cout << "Hand Mode: CLOSE" << std::endl;
	}else if(mode == 4){
		std::cout << "Hand Mode: CLOSE SLOWLY" << std::endl;
	}else {
		std::cout << "Hand Mode: UNKNOWN" << std::endl;
	}
  } 
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t HandTest::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t HandTest::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t HandTest::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t HandTest::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t HandTest::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void HandTestInit(RTC::Manager* manager)
  {
    coil::Properties profile(handtest_spec);
    manager->registerFactory(profile,
                             RTC::Create<HandTest>,
                             RTC::Delete<HandTest>);
  }
  
};


